@@ -4,32 +4,30 @@ data_location = os.path.join(__dir__, "data")
 src = "https://github.com/picolibc/picolibc"
 
 # Module version
-version_str = "1.7.8.post473"
-version_tuple = (1, 7, 8, 473)
+version_str = "1.7.9.post152"
+version_tuple = (1, 7, 9, 152)
 try:
     from packaging.version import Version as V
-    pversion = V("1.7.8.post473")
+    pversion = V("1.7.9.post152")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.7.8.post331"
-data_version_tuple = (1, 7, 8, 331)
+data_version_str = "1.7.9.post10"
+data_version_tuple = (1, 7, 9, 10)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.7.8.post331")
+    pdata_version = V("1.7.9.post10")
 except ImportError:
     pass
-data_git_hash = "5c5f2a2e2a46066fafae38d228e1550339578fd0"
-data_git_describe = "1.7.8-331-g5c5f2a2e2"
+data_git_hash = "8a98d4d6b5c9ae43d6a980bfd5678fe88fbdf35c"
+data_git_describe = "1.7.9-10-g8a98d4d6b"
 data_git_msg = """\
-commit 5c5f2a2e2a46066fafae38d228e1550339578fd0
+commit 8a98d4d6b5c9ae43d6a980bfd5678fe88fbdf35c
 Author: Keith Packard <keithp@keithp.com>
-Date:   Wed Sep 14 15:35:19 2022 +0100
+Date:   Wed Oct 19 10:33:39 2022 -0700
 
-    .github: Build MSP430 bits
-    
-    Use the TI MSP430 GNU SDK to build using both clang and gcc.
+    xtensa: Add _set_tls helper
     
     Signed-off-by: Keith Packard <keithp@keithp.com>
 
