@@ -41,6 +41,7 @@
 #include <unistd.h>
 #include <sys/config.h>
 #include <sys/lock.h>
+#include <stdint.h>
 
 #if MALLOC_DEBUG
 #include <assert.h>
@@ -57,10 +58,15 @@
 #define MAX(a,b) ((a) >= (b) ? (a) : (b))
 #endif
 
+#if __SIZEOF_POINTER__ == __SIZEOF_LONG__
 #define ALIGN_TO(size, align) \
     (((size) + (align) -1L) & ~((align) -1L))
+#else
+#define ALIGN_TO(size, align) \
+    (((size) + (align) -1) & ~((align) -1))
+#endif
 
-#define ALIGN_PTR(ptr, align)	(void *) ALIGN_TO((uintptr_t) ptr, align)
+#define ALIGN_PTR(ptr, align)	(void *) (uintptr_t) ALIGN_TO((uintptr_t) ptr, align)
 
 typedef struct {
     char c;
@@ -262,7 +268,7 @@ void* __malloc_sbrk_aligned(size_t s)
          * aligned to the right value as chunk sizes are selected to
          * make them abut in memory
 	 */
-	size_t adjust = align_p - p;
+	intptr_t adjust = align_p - p;
         char *extra = sbrk(adjust);
         if (extra != p + s)
             return (void *) -1;
@@ -641,7 +647,7 @@ struct mallinfo mallinfo(void)
     chunk_t * pf;
     size_t free_size = 0;
     size_t total_size;
-    int ordblks = 0;
+    size_t ordblks = 0;
     struct mallinfo current_mallinfo;
 
     MALLOC_LOCK;
@@ -746,7 +752,7 @@ void * memalign(size_t align, size_t s)
 
     aligned_p = ALIGN_PTR(allocated, align);
 
-    offset = aligned_p - allocated;
+    offset = (size_t) (aligned_p - allocated);
 
     /* Split off the front piece if necessary */
     if (offset)
