@@ -14,10 +14,9 @@
 	float y;
 #endif
 {
-  if (isnan(x)) return(x);
-  if (isnan(y)) return(y);
+  if (isnanf(x) || isnanf(y)) return(x+y);
 
-  float z = x > y ? x - y : 0.0;
+  float z = x > y ? x - y : (float)0.0;
   if (!isinf(x) && !isinf(y))
     z = check_oflowf(z);
   return z;
